MINOR: config: continue to rely on DEFAULT_MAXCONN to set the minimum maxconn

Some packages used to rely on DEFAULT_MAXCONN to set the default global
maxconn value to use regardless of the initial ulimit. The recent changes
made the lowest bound set to 100 so that it is compatible with almost any
environment. Now that DEFAULT_MAXCONN is not needed for anything else, we
can use it for the lowest bound set when maxconn is not configured. This
way it retains its original purpose of setting the default maxconn value
eventhough most of the time the effective value will be higher thanks to
the automatic computation based on "ulimit -n".
diff --git a/src/haproxy.c b/src/haproxy.c
index 7095d70..317aceb 100644
--- a/src/haproxy.c
+++ b/src/haproxy.c
@@ -1452,9 +1452,11 @@
 /* considers global.maxsocks, global.maxpipes, async engines, SSL frontends and
  * rlimits and computes an ideal maxconn. It's meant to be called only when
  * maxsock contains the sum of listening FDs, before it is updated based on
  * maxconn and pipes. If there are not enough FDs left, 100 is returned as it
  * is expected that it will even run on tight environments. The system will
  * emit a warning indicating how many FDs are missing anyway.
  */
 static int compute_ideal_maxconn()
 {
@@ -1495,7 +1497,7 @@
 		maxconn = remain / (2 + engine_fds);
 	}
 
-	return MAX(maxconn, 100);
+	return MAX(maxconn, DEFAULT_MAXCONN);
 }
 
 /*
@@ -1452,9 +1452,11 @@
  * rlimits and computes an ideal maxconn. It's meant to be called only when
  * maxsock contains the sum of listening FDs, before it is updated based on
- * maxconn and pipes. If there are not enough FDs left, 100 is returned as it
- * is expected that it will even run on tight environments. The system will
- * emit a warning indicating how many FDs are missing anyway.
+ * maxconn and pipes. If there are not enough FDs left, DEFAULT_MAXCONN (by
+ * default 100) is returned as it is expected that it will even run on tight
+ * environments, and will maintain compatibility with previous packages that
+ * used to rely on this value as the default one. The system will emit a
+ * warning indicating how many FDs are missing anyway if needed.
  */
 static int compute_ideal_maxconn()